// Code generated by ent, DO NOT EDIT.

package ent

import (
	"context"
	"database/sql/driver"
	"fmt"
	"math"
	"wechat-api/ent/contact"
	"wechat-api/ent/contactfield"
	"wechat-api/ent/labelrelationship"
	"wechat-api/ent/messagerecords"
	"wechat-api/ent/predicate"

	"entgo.io/ent/dialect/sql"
	"entgo.io/ent/dialect/sql/sqlgraph"
	"entgo.io/ent/schema/field"
)

// ContactQuery is the builder for querying Contact entities.
type ContactQuery struct {
	config
	ctx                      *QueryContext
	order                    []contact.OrderOption
	inters                   []Interceptor
	predicates               []predicate.Contact
	withContactRelationships *LabelRelationshipQuery
	withContactFields        *ContactFieldQuery
	withContactMessages      *MessageRecordsQuery
	// intermediate query (i.e. traversal path).
	sql  *sql.Selector
	path func(context.Context) (*sql.Selector, error)
}

// Where adds a new predicate for the ContactQuery builder.
func (cq *ContactQuery) Where(ps ...predicate.Contact) *ContactQuery {
	cq.predicates = append(cq.predicates, ps...)
	return cq
}

// Limit the number of records to be returned by this query.
func (cq *ContactQuery) Limit(limit int) *ContactQuery {
	cq.ctx.Limit = &limit
	return cq
}

// Offset to start from.
func (cq *ContactQuery) Offset(offset int) *ContactQuery {
	cq.ctx.Offset = &offset
	return cq
}

// Unique configures the query builder to filter duplicate records on query.
// By default, unique is set to true, and can be disabled using this method.
func (cq *ContactQuery) Unique(unique bool) *ContactQuery {
	cq.ctx.Unique = &unique
	return cq
}

// Order specifies how the records should be ordered.
func (cq *ContactQuery) Order(o ...contact.OrderOption) *ContactQuery {
	cq.order = append(cq.order, o...)
	return cq
}

// QueryContactRelationships chains the current query on the "contact_relationships" edge.
func (cq *ContactQuery) QueryContactRelationships() *LabelRelationshipQuery {
	query := (&LabelRelationshipClient{config: cq.config}).Query()
	query.path = func(ctx context.Context) (fromU *sql.Selector, err error) {
		if err := cq.prepareQuery(ctx); err != nil {
			return nil, err
		}
		selector := cq.sqlQuery(ctx)
		if err := selector.Err(); err != nil {
			return nil, err
		}
		step := sqlgraph.NewStep(
			sqlgraph.From(contact.Table, contact.FieldID, selector),
			sqlgraph.To(labelrelationship.Table, labelrelationship.FieldID),
			sqlgraph.Edge(sqlgraph.O2M, false, contact.ContactRelationshipsTable, contact.ContactRelationshipsColumn),
		)
		fromU = sqlgraph.SetNeighbors(cq.driver.Dialect(), step)
		return fromU, nil
	}
	return query
}

// QueryContactFields chains the current query on the "contact_fields" edge.
func (cq *ContactQuery) QueryContactFields() *ContactFieldQuery {
	query := (&ContactFieldClient{config: cq.config}).Query()
	query.path = func(ctx context.Context) (fromU *sql.Selector, err error) {
		if err := cq.prepareQuery(ctx); err != nil {
			return nil, err
		}
		selector := cq.sqlQuery(ctx)
		if err := selector.Err(); err != nil {
			return nil, err
		}
		step := sqlgraph.NewStep(
			sqlgraph.From(contact.Table, contact.FieldID, selector),
			sqlgraph.To(contactfield.Table, contactfield.FieldID),
			sqlgraph.Edge(sqlgraph.O2M, false, contact.ContactFieldsTable, contact.ContactFieldsColumn),
		)
		fromU = sqlgraph.SetNeighbors(cq.driver.Dialect(), step)
		return fromU, nil
	}
	return query
}

// QueryContactMessages chains the current query on the "contact_messages" edge.
func (cq *ContactQuery) QueryContactMessages() *MessageRecordsQuery {
	query := (&MessageRecordsClient{config: cq.config}).Query()
	query.path = func(ctx context.Context) (fromU *sql.Selector, err error) {
		if err := cq.prepareQuery(ctx); err != nil {
			return nil, err
		}
		selector := cq.sqlQuery(ctx)
		if err := selector.Err(); err != nil {
			return nil, err
		}
		step := sqlgraph.NewStep(
			sqlgraph.From(contact.Table, contact.FieldID, selector),
			sqlgraph.To(messagerecords.Table, messagerecords.FieldID),
			sqlgraph.Edge(sqlgraph.O2M, false, contact.ContactMessagesTable, contact.ContactMessagesColumn),
		)
		fromU = sqlgraph.SetNeighbors(cq.driver.Dialect(), step)
		return fromU, nil
	}
	return query
}

// First returns the first Contact entity from the query.
// Returns a *NotFoundError when no Contact was found.
func (cq *ContactQuery) First(ctx context.Context) (*Contact, error) {
	nodes, err := cq.Limit(1).All(setContextOp(ctx, cq.ctx, "First"))
	if err != nil {
		return nil, err
	}
	if len(nodes) == 0 {
		return nil, &NotFoundError{contact.Label}
	}
	return nodes[0], nil
}

// FirstX is like First, but panics if an error occurs.
func (cq *ContactQuery) FirstX(ctx context.Context) *Contact {
	node, err := cq.First(ctx)
	if err != nil && !IsNotFound(err) {
		panic(err)
	}
	return node
}

// FirstID returns the first Contact ID from the query.
// Returns a *NotFoundError when no Contact ID was found.
func (cq *ContactQuery) FirstID(ctx context.Context) (id uint64, err error) {
	var ids []uint64
	if ids, err = cq.Limit(1).IDs(setContextOp(ctx, cq.ctx, "FirstID")); err != nil {
		return
	}
	if len(ids) == 0 {
		err = &NotFoundError{contact.Label}
		return
	}
	return ids[0], nil
}

// FirstIDX is like FirstID, but panics if an error occurs.
func (cq *ContactQuery) FirstIDX(ctx context.Context) uint64 {
	id, err := cq.FirstID(ctx)
	if err != nil && !IsNotFound(err) {
		panic(err)
	}
	return id
}

// Only returns a single Contact entity found by the query, ensuring it only returns one.
// Returns a *NotSingularError when more than one Contact entity is found.
// Returns a *NotFoundError when no Contact entities are found.
func (cq *ContactQuery) Only(ctx context.Context) (*Contact, error) {
	nodes, err := cq.Limit(2).All(setContextOp(ctx, cq.ctx, "Only"))
	if err != nil {
		return nil, err
	}
	switch len(nodes) {
	case 1:
		return nodes[0], nil
	case 0:
		return nil, &NotFoundError{contact.Label}
	default:
		return nil, &NotSingularError{contact.Label}
	}
}

// OnlyX is like Only, but panics if an error occurs.
func (cq *ContactQuery) OnlyX(ctx context.Context) *Contact {
	node, err := cq.Only(ctx)
	if err != nil {
		panic(err)
	}
	return node
}

// OnlyID is like Only, but returns the only Contact ID in the query.
// Returns a *NotSingularError when more than one Contact ID is found.
// Returns a *NotFoundError when no entities are found.
func (cq *ContactQuery) OnlyID(ctx context.Context) (id uint64, err error) {
	var ids []uint64
	if ids, err = cq.Limit(2).IDs(setContextOp(ctx, cq.ctx, "OnlyID")); err != nil {
		return
	}
	switch len(ids) {
	case 1:
		id = ids[0]
	case 0:
		err = &NotFoundError{contact.Label}
	default:
		err = &NotSingularError{contact.Label}
	}
	return
}

// OnlyIDX is like OnlyID, but panics if an error occurs.
func (cq *ContactQuery) OnlyIDX(ctx context.Context) uint64 {
	id, err := cq.OnlyID(ctx)
	if err != nil {
		panic(err)
	}
	return id
}

// All executes the query and returns a list of Contacts.
func (cq *ContactQuery) All(ctx context.Context) ([]*Contact, error) {
	ctx = setContextOp(ctx, cq.ctx, "All")
	if err := cq.prepareQuery(ctx); err != nil {
		return nil, err
	}
	qr := querierAll[[]*Contact, *ContactQuery]()
	return withInterceptors[[]*Contact](ctx, cq, qr, cq.inters)
}

// AllX is like All, but panics if an error occurs.
func (cq *ContactQuery) AllX(ctx context.Context) []*Contact {
	nodes, err := cq.All(ctx)
	if err != nil {
		panic(err)
	}
	return nodes
}

// IDs executes the query and returns a list of Contact IDs.
func (cq *ContactQuery) IDs(ctx context.Context) (ids []uint64, err error) {
	if cq.ctx.Unique == nil && cq.path != nil {
		cq.Unique(true)
	}
	ctx = setContextOp(ctx, cq.ctx, "IDs")
	if err = cq.Select(contact.FieldID).Scan(ctx, &ids); err != nil {
		return nil, err
	}
	return ids, nil
}

// IDsX is like IDs, but panics if an error occurs.
func (cq *ContactQuery) IDsX(ctx context.Context) []uint64 {
	ids, err := cq.IDs(ctx)
	if err != nil {
		panic(err)
	}
	return ids
}

// Count returns the count of the given query.
func (cq *ContactQuery) Count(ctx context.Context) (int, error) {
	ctx = setContextOp(ctx, cq.ctx, "Count")
	if err := cq.prepareQuery(ctx); err != nil {
		return 0, err
	}
	return withInterceptors[int](ctx, cq, querierCount[*ContactQuery](), cq.inters)
}

// CountX is like Count, but panics if an error occurs.
func (cq *ContactQuery) CountX(ctx context.Context) int {
	count, err := cq.Count(ctx)
	if err != nil {
		panic(err)
	}
	return count
}

// Exist returns true if the query has elements in the graph.
func (cq *ContactQuery) Exist(ctx context.Context) (bool, error) {
	ctx = setContextOp(ctx, cq.ctx, "Exist")
	switch _, err := cq.FirstID(ctx); {
	case IsNotFound(err):
		return false, nil
	case err != nil:
		return false, fmt.Errorf("ent: check existence: %w", err)
	default:
		return true, nil
	}
}

// ExistX is like Exist, but panics if an error occurs.
func (cq *ContactQuery) ExistX(ctx context.Context) bool {
	exist, err := cq.Exist(ctx)
	if err != nil {
		panic(err)
	}
	return exist
}

// Clone returns a duplicate of the ContactQuery builder, including all associated steps. It can be
// used to prepare common query builders and use them differently after the clone is made.
func (cq *ContactQuery) Clone() *ContactQuery {
	if cq == nil {
		return nil
	}
	return &ContactQuery{
		config:                   cq.config,
		ctx:                      cq.ctx.Clone(),
		order:                    append([]contact.OrderOption{}, cq.order...),
		inters:                   append([]Interceptor{}, cq.inters...),
		predicates:               append([]predicate.Contact{}, cq.predicates...),
		withContactRelationships: cq.withContactRelationships.Clone(),
		withContactFields:        cq.withContactFields.Clone(),
		withContactMessages:      cq.withContactMessages.Clone(),
		// clone intermediate query.
		sql:  cq.sql.Clone(),
		path: cq.path,
	}
}

// WithContactRelationships tells the query-builder to eager-load the nodes that are connected to
// the "contact_relationships" edge. The optional arguments are used to configure the query builder of the edge.
func (cq *ContactQuery) WithContactRelationships(opts ...func(*LabelRelationshipQuery)) *ContactQuery {
	query := (&LabelRelationshipClient{config: cq.config}).Query()
	for _, opt := range opts {
		opt(query)
	}
	cq.withContactRelationships = query
	return cq
}

// WithContactFields tells the query-builder to eager-load the nodes that are connected to
// the "contact_fields" edge. The optional arguments are used to configure the query builder of the edge.
func (cq *ContactQuery) WithContactFields(opts ...func(*ContactFieldQuery)) *ContactQuery {
	query := (&ContactFieldClient{config: cq.config}).Query()
	for _, opt := range opts {
		opt(query)
	}
	cq.withContactFields = query
	return cq
}

// WithContactMessages tells the query-builder to eager-load the nodes that are connected to
// the "contact_messages" edge. The optional arguments are used to configure the query builder of the edge.
func (cq *ContactQuery) WithContactMessages(opts ...func(*MessageRecordsQuery)) *ContactQuery {
	query := (&MessageRecordsClient{config: cq.config}).Query()
	for _, opt := range opts {
		opt(query)
	}
	cq.withContactMessages = query
	return cq
}

// GroupBy is used to group vertices by one or more fields/columns.
// It is often used with aggregate functions, like: count, max, mean, min, sum.
//
// Example:
//
//	var v []struct {
//		CreatedAt time.Time `json:"created_at,omitempty"`
//		Count int `json:"count,omitempty"`
//	}
//
//	client.Contact.Query().
//		GroupBy(contact.FieldCreatedAt).
//		Aggregate(ent.Count()).
//		Scan(ctx, &v)
func (cq *ContactQuery) GroupBy(field string, fields ...string) *ContactGroupBy {
	cq.ctx.Fields = append([]string{field}, fields...)
	grbuild := &ContactGroupBy{build: cq}
	grbuild.flds = &cq.ctx.Fields
	grbuild.label = contact.Label
	grbuild.scan = grbuild.Scan
	return grbuild
}

// Select allows the selection one or more fields/columns for the given query,
// instead of selecting all fields in the entity.
//
// Example:
//
//	var v []struct {
//		CreatedAt time.Time `json:"created_at,omitempty"`
//	}
//
//	client.Contact.Query().
//		Select(contact.FieldCreatedAt).
//		Scan(ctx, &v)
func (cq *ContactQuery) Select(fields ...string) *ContactSelect {
	cq.ctx.Fields = append(cq.ctx.Fields, fields...)
	sbuild := &ContactSelect{ContactQuery: cq}
	sbuild.label = contact.Label
	sbuild.flds, sbuild.scan = &cq.ctx.Fields, sbuild.Scan
	return sbuild
}

// Aggregate returns a ContactSelect configured with the given aggregations.
func (cq *ContactQuery) Aggregate(fns ...AggregateFunc) *ContactSelect {
	return cq.Select().Aggregate(fns...)
}

func (cq *ContactQuery) prepareQuery(ctx context.Context) error {
	for _, inter := range cq.inters {
		if inter == nil {
			return fmt.Errorf("ent: uninitialized interceptor (forgotten import ent/runtime?)")
		}
		if trv, ok := inter.(Traverser); ok {
			if err := trv.Traverse(ctx, cq); err != nil {
				return err
			}
		}
	}
	for _, f := range cq.ctx.Fields {
		if !contact.ValidColumn(f) {
			return &ValidationError{Name: f, err: fmt.Errorf("ent: invalid field %q for query", f)}
		}
	}
	if cq.path != nil {
		prev, err := cq.path(ctx)
		if err != nil {
			return err
		}
		cq.sql = prev
	}
	return nil
}

func (cq *ContactQuery) sqlAll(ctx context.Context, hooks ...queryHook) ([]*Contact, error) {
	var (
		nodes       = []*Contact{}
		_spec       = cq.querySpec()
		loadedTypes = [3]bool{
			cq.withContactRelationships != nil,
			cq.withContactFields != nil,
			cq.withContactMessages != nil,
		}
	)
	_spec.ScanValues = func(columns []string) ([]any, error) {
		return (*Contact).scanValues(nil, columns)
	}
	_spec.Assign = func(columns []string, values []any) error {
		node := &Contact{config: cq.config}
		nodes = append(nodes, node)
		node.Edges.loadedTypes = loadedTypes
		return node.assignValues(columns, values)
	}
	for i := range hooks {
		hooks[i](ctx, _spec)
	}
	if err := sqlgraph.QueryNodes(ctx, cq.driver, _spec); err != nil {
		return nil, err
	}
	if len(nodes) == 0 {
		return nodes, nil
	}
	if query := cq.withContactRelationships; query != nil {
		if err := cq.loadContactRelationships(ctx, query, nodes,
			func(n *Contact) { n.Edges.ContactRelationships = []*LabelRelationship{} },
			func(n *Contact, e *LabelRelationship) {
				n.Edges.ContactRelationships = append(n.Edges.ContactRelationships, e)
			}); err != nil {
			return nil, err
		}
	}
	if query := cq.withContactFields; query != nil {
		if err := cq.loadContactFields(ctx, query, nodes,
			func(n *Contact) { n.Edges.ContactFields = []*ContactField{} },
			func(n *Contact, e *ContactField) { n.Edges.ContactFields = append(n.Edges.ContactFields, e) }); err != nil {
			return nil, err
		}
	}
	if query := cq.withContactMessages; query != nil {
		if err := cq.loadContactMessages(ctx, query, nodes,
			func(n *Contact) { n.Edges.ContactMessages = []*MessageRecords{} },
			func(n *Contact, e *MessageRecords) { n.Edges.ContactMessages = append(n.Edges.ContactMessages, e) }); err != nil {
			return nil, err
		}
	}
	return nodes, nil
}

func (cq *ContactQuery) loadContactRelationships(ctx context.Context, query *LabelRelationshipQuery, nodes []*Contact, init func(*Contact), assign func(*Contact, *LabelRelationship)) error {
	fks := make([]driver.Value, 0, len(nodes))
	nodeids := make(map[uint64]*Contact)
	for i := range nodes {
		fks = append(fks, nodes[i].ID)
		nodeids[nodes[i].ID] = nodes[i]
		if init != nil {
			init(nodes[i])
		}
	}
	if len(query.ctx.Fields) > 0 {
		query.ctx.AppendFieldOnce(labelrelationship.FieldContactID)
	}
	query.Where(predicate.LabelRelationship(func(s *sql.Selector) {
		s.Where(sql.InValues(s.C(contact.ContactRelationshipsColumn), fks...))
	}))
	neighbors, err := query.All(ctx)
	if err != nil {
		return err
	}
	for _, n := range neighbors {
		fk := n.ContactID
		node, ok := nodeids[fk]
		if !ok {
			return fmt.Errorf(`unexpected referenced foreign-key "contact_id" returned %v for node %v`, fk, n.ID)
		}
		assign(node, n)
	}
	return nil
}
func (cq *ContactQuery) loadContactFields(ctx context.Context, query *ContactFieldQuery, nodes []*Contact, init func(*Contact), assign func(*Contact, *ContactField)) error {
	fks := make([]driver.Value, 0, len(nodes))
	nodeids := make(map[uint64]*Contact)
	for i := range nodes {
		fks = append(fks, nodes[i].ID)
		nodeids[nodes[i].ID] = nodes[i]
		if init != nil {
			init(nodes[i])
		}
	}
	if len(query.ctx.Fields) > 0 {
		query.ctx.AppendFieldOnce(contactfield.FieldContactID)
	}
	query.Where(predicate.ContactField(func(s *sql.Selector) {
		s.Where(sql.InValues(s.C(contact.ContactFieldsColumn), fks...))
	}))
	neighbors, err := query.All(ctx)
	if err != nil {
		return err
	}
	for _, n := range neighbors {
		fk := n.ContactID
		node, ok := nodeids[fk]
		if !ok {
			return fmt.Errorf(`unexpected referenced foreign-key "contact_id" returned %v for node %v`, fk, n.ID)
		}
		assign(node, n)
	}
	return nil
}
func (cq *ContactQuery) loadContactMessages(ctx context.Context, query *MessageRecordsQuery, nodes []*Contact, init func(*Contact), assign func(*Contact, *MessageRecords)) error {
	fks := make([]driver.Value, 0, len(nodes))
	nodeids := make(map[uint64]*Contact)
	for i := range nodes {
		fks = append(fks, nodes[i].ID)
		nodeids[nodes[i].ID] = nodes[i]
		if init != nil {
			init(nodes[i])
		}
	}
	if len(query.ctx.Fields) > 0 {
		query.ctx.AppendFieldOnce(messagerecords.FieldContactID)
	}
	query.Where(predicate.MessageRecords(func(s *sql.Selector) {
		s.Where(sql.InValues(s.C(contact.ContactMessagesColumn), fks...))
	}))
	neighbors, err := query.All(ctx)
	if err != nil {
		return err
	}
	for _, n := range neighbors {
		fk := n.ContactID
		node, ok := nodeids[fk]
		if !ok {
			return fmt.Errorf(`unexpected referenced foreign-key "contact_id" returned %v for node %v`, fk, n.ID)
		}
		assign(node, n)
	}
	return nil
}

func (cq *ContactQuery) sqlCount(ctx context.Context) (int, error) {
	_spec := cq.querySpec()
	_spec.Node.Columns = cq.ctx.Fields
	if len(cq.ctx.Fields) > 0 {
		_spec.Unique = cq.ctx.Unique != nil && *cq.ctx.Unique
	}
	return sqlgraph.CountNodes(ctx, cq.driver, _spec)
}

func (cq *ContactQuery) querySpec() *sqlgraph.QuerySpec {
	_spec := sqlgraph.NewQuerySpec(contact.Table, contact.Columns, sqlgraph.NewFieldSpec(contact.FieldID, field.TypeUint64))
	_spec.From = cq.sql
	if unique := cq.ctx.Unique; unique != nil {
		_spec.Unique = *unique
	} else if cq.path != nil {
		_spec.Unique = true
	}
	if fields := cq.ctx.Fields; len(fields) > 0 {
		_spec.Node.Columns = make([]string, 0, len(fields))
		_spec.Node.Columns = append(_spec.Node.Columns, contact.FieldID)
		for i := range fields {
			if fields[i] != contact.FieldID {
				_spec.Node.Columns = append(_spec.Node.Columns, fields[i])
			}
		}
	}
	if ps := cq.predicates; len(ps) > 0 {
		_spec.Predicate = func(selector *sql.Selector) {
			for i := range ps {
				ps[i](selector)
			}
		}
	}
	if limit := cq.ctx.Limit; limit != nil {
		_spec.Limit = *limit
	}
	if offset := cq.ctx.Offset; offset != nil {
		_spec.Offset = *offset
	}
	if ps := cq.order; len(ps) > 0 {
		_spec.Order = func(selector *sql.Selector) {
			for i := range ps {
				ps[i](selector)
			}
		}
	}
	return _spec
}

func (cq *ContactQuery) sqlQuery(ctx context.Context) *sql.Selector {
	builder := sql.Dialect(cq.driver.Dialect())
	t1 := builder.Table(contact.Table)
	columns := cq.ctx.Fields
	if len(columns) == 0 {
		columns = contact.Columns
	}
	selector := builder.Select(t1.Columns(columns...)...).From(t1)
	if cq.sql != nil {
		selector = cq.sql
		selector.Select(selector.Columns(columns...)...)
	}
	if cq.ctx.Unique != nil && *cq.ctx.Unique {
		selector.Distinct()
	}
	for _, p := range cq.predicates {
		p(selector)
	}
	for _, p := range cq.order {
		p(selector)
	}
	if offset := cq.ctx.Offset; offset != nil {
		// limit is mandatory for offset clause. We start
		// with default value, and override it below if needed.
		selector.Offset(*offset).Limit(math.MaxInt32)
	}
	if limit := cq.ctx.Limit; limit != nil {
		selector.Limit(*limit)
	}
	return selector
}

// ContactGroupBy is the group-by builder for Contact entities.
type ContactGroupBy struct {
	selector
	build *ContactQuery
}

// Aggregate adds the given aggregation functions to the group-by query.
func (cgb *ContactGroupBy) Aggregate(fns ...AggregateFunc) *ContactGroupBy {
	cgb.fns = append(cgb.fns, fns...)
	return cgb
}

// Scan applies the selector query and scans the result into the given value.
func (cgb *ContactGroupBy) Scan(ctx context.Context, v any) error {
	ctx = setContextOp(ctx, cgb.build.ctx, "GroupBy")
	if err := cgb.build.prepareQuery(ctx); err != nil {
		return err
	}
	return scanWithInterceptors[*ContactQuery, *ContactGroupBy](ctx, cgb.build, cgb, cgb.build.inters, v)
}

func (cgb *ContactGroupBy) sqlScan(ctx context.Context, root *ContactQuery, v any) error {
	selector := root.sqlQuery(ctx).Select()
	aggregation := make([]string, 0, len(cgb.fns))
	for _, fn := range cgb.fns {
		aggregation = append(aggregation, fn(selector))
	}
	if len(selector.SelectedColumns()) == 0 {
		columns := make([]string, 0, len(*cgb.flds)+len(cgb.fns))
		for _, f := range *cgb.flds {
			columns = append(columns, selector.C(f))
		}
		columns = append(columns, aggregation...)
		selector.Select(columns...)
	}
	selector.GroupBy(selector.Columns(*cgb.flds...)...)
	if err := selector.Err(); err != nil {
		return err
	}
	rows := &sql.Rows{}
	query, args := selector.Query()
	if err := cgb.build.driver.Query(ctx, query, args, rows); err != nil {
		return err
	}
	defer rows.Close()
	return sql.ScanSlice(rows, v)
}

// ContactSelect is the builder for selecting fields of Contact entities.
type ContactSelect struct {
	*ContactQuery
	selector
}

// Aggregate adds the given aggregation functions to the selector query.
func (cs *ContactSelect) Aggregate(fns ...AggregateFunc) *ContactSelect {
	cs.fns = append(cs.fns, fns...)
	return cs
}

// Scan applies the selector query and scans the result into the given value.
func (cs *ContactSelect) Scan(ctx context.Context, v any) error {
	ctx = setContextOp(ctx, cs.ctx, "Select")
	if err := cs.prepareQuery(ctx); err != nil {
		return err
	}
	return scanWithInterceptors[*ContactQuery, *ContactSelect](ctx, cs.ContactQuery, cs, cs.inters, v)
}

func (cs *ContactSelect) sqlScan(ctx context.Context, root *ContactQuery, v any) error {
	selector := root.sqlQuery(ctx)
	aggregation := make([]string, 0, len(cs.fns))
	for _, fn := range cs.fns {
		aggregation = append(aggregation, fn(selector))
	}
	switch n := len(*cs.selector.flds); {
	case n == 0 && len(aggregation) > 0:
		selector.Select(aggregation...)
	case n != 0 && len(aggregation) > 0:
		selector.AppendSelect(aggregation...)
	}
	rows := &sql.Rows{}
	query, args := selector.Query()
	if err := cs.driver.Query(ctx, query, args, rows); err != nil {
		return err
	}
	defer rows.Close()
	return sql.ScanSlice(rows, v)
}
