package chatrecords

import (
	"net/http"
	jwtutils "wechat-api/internal/utils/jwt"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/chatrecords"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /gpts/chat/message chatrecords GptsGetApiMessage
//
// Create chat records information | 创建ChatRecords
//
// Create chat records information | 创建ChatRecords
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: GptMessageReq
//
// Responses:
//  200: GptMessageResp

func GptsGetApiMessageHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.GptMessageReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}
		tokenStr := jwtutils.StripBearerPrefixFromToken(r.Header.Get("Authorization"))
		l := chatrecords.NewGptsGetApiMessageLogic(r.Context(), svcCtx)
		resp, err := l.GptsGetApiMessage(&req, tokenStr)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
