package dashboard

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/dashboard"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /dashboard/charts dashboard GetCharts
//
// get charts | 获取图表数据
//
// get charts | 获取图表数据
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: ChartsReq
//
// Responses:
//  200: ChartsResp

func GetChartsHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.ChartsReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := dashboard.NewGetChartsLogic(r.Context(), svcCtx)
		resp, err := l.GetCharts(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
