package whatsapp

import (
	"net/http"

	"github.com/zeromicro/go-zero/rest/httpx"

	"wechat-api/internal/logic/whatsapp"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
)

// swagger:route post /whatsapp whatsapp GetWhatsappById
//
// Get whatsapp by ID | 通过ID获取Whatsapp
//
// Get whatsapp by ID | 通过ID获取Whatsapp
//
// Parameters:
//  + name: body
//    require: true
//    in: body
//    type: IDReq
//
// Responses:
//  200: WhatsappInfoResp

func GetWhatsappByIdHandler(svcCtx *svc.ServiceContext) http.HandlerFunc {
	return func(w http.ResponseWriter, r *http.Request) {
		var req types.IDReq
		if err := httpx.Parse(r, &req, true); err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
			return
		}

		l := whatsapp.NewGetWhatsappByIdLogic(r.Context(), svcCtx)
		resp, err := l.GetWhatsappById(&req)
		if err != nil {
			httpx.ErrorCtx(r.Context(), w, err)
		} else {
			httpx.OkJsonCtx(r.Context(), w, resp)
		}
	}
}
