package UsageDetail

import (
	"context"
	"github.com/suyuan32/simple-admin-common/msg/errormsg"
	"github.com/suyuan32/simple-admin-common/utils/pointy"
	"github.com/suyuan32/simple-admin-core/rpc/types/core"
	"time"
	"wechat-api/ent/predicate"
	"wechat-api/ent/usagedetail"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
	"wechat-api/internal/utils/dberrorhandler"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetUsageDetailListLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetUsageDetailListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetUsageDetailListLogic {
	return &GetUsageDetailListLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx}
}

func (l *GetUsageDetailListLogic) GetUsageDetailList(req *types.UsageDetailListReq) (resp *types.UsageDetailListResp, err error) {
	organizationId := l.ctx.Value("organizationId").(uint64)
	isAdmin := l.ctx.Value("isAdmin").(bool)

	var predicates []predicate.UsageDetail

	if !isAdmin {
		predicates = append(predicates, usagedetail.OrganizationIDEQ(organizationId))
	} else {
		if req.OrganizationId != nil && *req.OrganizationId > 0 {
			predicates = append(predicates, usagedetail.OrganizationIDEQ(*req.OrganizationId))
		}
	}

	if req.Type != nil && *req.Type > 0 {
		predicates = append(predicates, usagedetail.TypeEQ(*req.Type))
	}
	if req.BotId != nil && *req.BotId != "" {
		predicates = append(predicates, usagedetail.BotID(*req.BotId))
	}
	if req.ReceiverId != nil && *req.ReceiverId != "" {
		predicates = append(predicates, usagedetail.ReceiverID(*req.ReceiverId))
	}
	// 这里是为限制时间段
	if req.SearchDate != nil && len(req.SearchDate) == 2 {
		startDate, err := time.Parse("2006-01-02 15:04:05", req.SearchDate[0])
		if err != nil {
			l.Logger.Errorf("时间字符串startDate转换错误: %v", err)
		} else {
			predicates = append(predicates, usagedetail.CreatedAtGTE(startDate))
		}

		endDate, err := time.Parse("2006-01-02 15:04:05", req.SearchDate[1])
		if err != nil {
			l.Logger.Errorf("时间字符串endDate转换错误: %v", err)
		} else {
			predicates = append(predicates, usagedetail.CreatedAtLTE(endDate))
		}
	}

	data, err := l.svcCtx.DB.UsageDetail.Query().Where(predicates...).Page(l.ctx, req.Page, req.PageSize)

	if err != nil {
		return nil, dberrorhandler.DefaultEntError(l.Logger, err, req)
	}

	resp = &types.UsageDetailListResp{}
	resp.Msg = errormsg.Success
	resp.Data.Total = data.PageDetails.Total

	orgaMap := make(map[uint64]string)

	for _, v := range data.List {
		app := "未知"
		if v.App == 1 {
			app = "智能回复"
		} else if v.App == 2 {
			app = "AI角色-优化问题"
		} else if v.App == 3 {
			app = "AI角色-回复"
		} else if v.App == 4 {
			app = "SOP-节点判断"
		} else if v.App == 5 {
			app = "SOP-节点判断"
		}
		request := v.Request
		if v.App == 2 {
			request = "问题优化"
		} else if v.App == 4 {
			request = "节点判断"
		}

		organizationName := ""
		if oname, ok := orgaMap[v.OrganizationID]; ok {
			organizationName = oname
		} else {
			departmentInfo, err := l.svcCtx.CoreRpc.GetDepartmentById(l.ctx, &core.IDReq{Id: v.OrganizationID})
			if err == nil {
				organizationName = *departmentInfo.Name
				orgaMap[v.OrganizationID] = organizationName
			}
		}

		resp.Data.Data = append(resp.Data.Data,
			types.UsageDetailInfo{
				BaseIDInfo: types.BaseIDInfo{
					Id:        &v.ID,
					CreatedAt: pointy.GetPointer(v.CreatedAt.UnixMilli()),
					//UpdatedAt: pointy.GetPointer(v.UpdatedAt.UnixMilli()),
				},
				//Status:      &v.Status,
				Type:       &v.Type,
				BotId:      &v.BotID,
				ReceiverId: &v.ReceiverID,
				App:        &app,
				//SessionId:   &v.SessionID,
				Request:     &request,
				Response:    &v.Response,
				TotalTokens: &v.TotalTokens,
				//PromptTokens:     &v.PromptTokens,
				//CompletionTokens: &v.CompletionTokens,
				OrganizationId:   &v.OrganizationID,
				OrganizationName: &organizationName,
				Model:            &v.Model,
				Credits:          &v.Credits,
			})
	}

	return resp, nil
	//return nil, nil
}
