package allocagent

import (
	"context"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
	"wechat-api/internal/utils/dberrorhandler"

	"github.com/suyuan32/simple-admin-common/msg/errormsg"

	"github.com/suyuan32/simple-admin-common/utils/pointy"
	"github.com/zeromicro/go-zero/core/logx"
)

type GetAllocAgentByIdLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetAllocAgentByIdLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetAllocAgentByIdLogic {
	return &GetAllocAgentByIdLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *GetAllocAgentByIdLogic) GetAllocAgentById(req *types.IDReq) (*types.AllocAgentInfoResp, error) {
	data, err := l.svcCtx.DB.AllocAgent.Get(l.ctx, req.Id)
	if err != nil {
		return nil, dberrorhandler.DefaultEntError(l.Logger, err, req)
	}

	return &types.AllocAgentInfoResp{
		BaseDataInfo: types.BaseDataInfo{
			Code: 0,
			Msg:  errormsg.Success,
		},
		Data: types.AllocAgentInfo{
			BaseIDInfo: types.BaseIDInfo{
				Id:        &data.ID,
				CreatedAt: pointy.GetPointer(data.CreatedAt.UnixMilli()),
				UpdatedAt: pointy.GetPointer(data.UpdatedAt.UnixMilli()),
			},
			UserId:         &data.UserID,
			OrganizationId: &data.OrganizationID,
			Agents:         data.Agents,
			Status:         &data.Status,
		},
	}, nil
}
