package whatsapp

import (
	"context"

	"wechat-api/ent/whatsapp"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
	"wechat-api/internal/utils/dberrorhandler"

	"github.com/suyuan32/simple-admin-common/msg/errormsg"
	"github.com/zeromicro/go-zero/core/logx"
)

type DeleteWhatsappLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewDeleteWhatsappLogic(ctx context.Context, svcCtx *svc.ServiceContext) *DeleteWhatsappLogic {
	return &DeleteWhatsappLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *DeleteWhatsappLogic) DeleteWhatsapp(req *types.IDsReq) (*types.BaseMsgResp, error) {
	_, err := l.svcCtx.DB.Whatsapp.Delete().Where(whatsapp.IDIn(req.Ids...)).Exec(l.ctx)

	if err != nil {
		return nil, dberrorhandler.DefaultEntError(l.Logger, err, req)
	}

	_ = l.svcCtx.Rds.Del(l.ctx, "wa_info")

	return &types.BaseMsgResp{Msg: errormsg.DeleteSuccess}, nil
}
