package wechat

import (
	"context"
	"fmt"
	"github.com/imroc/req/v3"
	"github.com/zeromicro/go-zero/core/logx"
	"strconv"
	"time"
	"wechat-api/ent"
	"wechat-api/ent/wx"
	"wechat-api/internal/types"
)

type SyncWx struct {
	Ctx context.Context
	DB  *ent.Client
}

func (s *SyncWx) SyncAll() {
	// 获取微信列表
	var result types.WorkPhoneGetWeChatsResp
	client := req.C().DevMode()
	client.SetCommonRetryCount(2).
		SetCommonRetryBackoffInterval(1*time.Second, 5*time.Second).
		SetCommonRetryFixedInterval(2 * time.Second).SetTimeout(30 * time.Second)
	res, err := client.R().SetSuccessResult(&result).Post("http://chat-debug.gkscrm.com:13086/pc/GetWeChatsReq?id=0")
	if err != nil {
		logx.Error("syncWx： ", err)
		return
	}
	if !res.IsSuccessState() {
		logx.Error("GetWeChats failed with status code： ", res.StatusCode)
		return
	}

	// 遍历微信列表
	for _, account := range result.Data {
		if account.Wechatid == nil || *account.Wechatid == "" {
			continue
		}
		wxinfo, err := s.DB.Wx.Query().
			Where(
				wx.And(
					wx.WxidEQ(*account.Wechatid),
					wx.CtypeEQ(1),
				),
			).
			Only(s.Ctx)

		if err != nil && !ent.IsNotFound(err) {
			logx.Error("syncWx： ", err)
			return
		}

		var status uint8
		logx.Info(fmt.Printf("*account.Isonline： %d\n", *account.Isonline))
		if *account.Isonline == 0 {
			status = 1
		} else {
			status = 0
		}

		if wxinfo != nil {
			tx, err := s.DB.Tx(s.Ctx)
			if err != nil {
				continue
			}
			defer tx.Rollback()
			change := WxSafeChange{Ctx: s.Ctx, Tx: tx, WxId: wxinfo.Wxid, OrganizationId: wxinfo.OrganizationID}
			err = change.KeepAllSafe()
			if err != nil {
				_ = tx.Rollback()
				continue
			}
			logx.Info(fmt.Printf("wxinfo is not nil, account： %s\n", *account.Wechatid))
			logx.Info(fmt.Printf("wxinfo is not nil, account： %s\n", *account.Wechatnick))
			err = tx.Wx.UpdateOneID(wxinfo.ID).
				SetServerID(0).
				SetPort(*account.Deviceid).
				SetProcessID(strconv.FormatInt(account.Cid, 10)).
				SetNotNilAccount(account.Wechatno).
				SetNotNilNickname(account.Wechatnick).
				SetNotNilHeadBig(account.Avatar).
				SetStatus(status).
				Exec(s.Ctx)
			if err != nil {
				_ = tx.Rollback()
				logx.Error("syncWx： ", err)
				continue
			}
			err = tx.Commit()
			if err != nil {
				logx.Error("syncWx： ", err)
				continue
			}
		} else {
			logx.Error(fmt.Printf("wxinfo is nil, account： %+v\n", account))
			_, err := s.DB.Wx.Create().
				SetServerID(0).
				SetPort(*account.Deviceid).
				SetProcessID(strconv.FormatInt(account.Cid, 10)).
				SetWxid(*account.Wechatid).
				SetNotNilAccount(account.Wechatno).
				SetNotNilHeadBig(account.Avatar).
				SetNotNilNickname(account.Wechatnick).
				SetStatus(status).
				SetAllowList([]string{}).SetBlockList([]string{}).SetGroupAllowList([]string{}).SetGroupBlockList([]string{}).
				Save(s.Ctx)
			if err != nil {
				logx.Error("syncWx： ", err)
				continue
			}
		}
	}
}
