package utils

import "time"

// IsNonEmptyString 判断字符串指针不为 nil 且不为空
func IsNonEmptyString(s *string) bool {
	return s != nil && *s != ""
}

// UnixTimeToBeijing 将 Unix 时间戳转换为北京时间字符串
func UnixTimeToBeijing(i any) *string {
	// 断言输入为 int64 类型
	unixTime, ok := i.(int64)
	if !ok {
		return nil
	}

	// 当传入的时间为0值时，返回固定字符串"---"
	if unixTime == 0 {
		defaultTime := "--"
		return &defaultTime
	}

	// 转换为北京时间（UTC+8）
	beijingTime := time.Unix(unixTime, 0).In(time.FixedZone("CST", 8*3600))

	// 格式化时间字符串
	formattedTime := beijingTime.Format("2006-01-02 15:04:05")

	// 返回字符串指针
	return &formattedTime
}
